@@ -459,8 +459,9 @@ class CControllerMenuPopup extends CController {
 				unset($selement['urls'][$url_nr]);
 			}
 			elseif (CHtmlUrlValidator::validate($url['url'], ['allow_user_macro' => false]) === false) {
-				$selement['urls'][$url_nr]['url'] = 'javascript: alert(\''._s('Provided URL "%1$s" is invalid.',
-					zbx_jsvalue($url['url'], false, false)).'\');';
+				$selement['urls'][$url_nr]['url'] = 'javascript: alert('.
+					json_encode(_s('Provided URL "%1$s" is invalid.', $url['url'])).
+				');';
 			}
 		}
 
@@ -740,9 +741,9 @@ class CControllerMenuPopup extends CController {
 			if (array_key_exists('urls', $menu_data)) {
 				foreach ($menu_data['urls'] as &$url) {
 					if (!CHtmlUrlValidator::validate($url['url'], ['allow_user_macro' => false])) {
-						$url['url'] = 'javascript: alert(\''.
-							_s('Provided URL "%1$s" is invalid.', zbx_jsvalue($url['url'], false, false)).
-						'\');';
+						$url['url'] = 'javascript: alert('.
+							json_encode(_s('Provided URL "%1$s" is invalid.', $url['url'])).
+						');';
 						unset($url['target'], $url['rel']);
 					}
 				}
