@@ -67,6 +67,7 @@ else {
 				->addClass('macro')
 				->setWidth(ZBX_TEXTAREA_MACRO_WIDTH)
 				->setAttribute('placeholder', '{$MACRO}')
+				->disableSpellcheck()
 		];
 
 		if (!$data['readonly']) {
@@ -130,7 +131,7 @@ else {
 
 		// Parent host macro value.
 		if ($is_hostprototype) {
-			$row[] = array_key_exists('parent_host', $macro) ? '&lArr;' : '';
+			$row[] = array_key_exists('parent_host', $macro) ? LARR() : '';
 			$row[] = (new CDiv(array_key_exists('parent_host', $macro) ? '"'.$macro['parent_host']['value'].'"' : null))
 				->setAdaptiveWidth($inherited_width)
 				->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS);
@@ -141,26 +142,26 @@ else {
 
 		if (array_key_exists('template', $macro)) {
 			if ($macro['template']['rights'] == PERM_READ_WRITE) {
-				$link = (new CLink(CHtml::encode($macro['template']['name']),
+				$link = (new CLink($macro['template']['name'],
 					'templates.php?form=update&templateid='.$macro['template']['templateid'])
 				)
 					->addClass('unknown')
 					->setTarget('_blank');
 			}
 			else {
-				$link = new CSpan(CHtml::encode($macro['template']['name']));
+				$link = new CSpan($macro['template']['name']);
 			}
 
 			$template_macro = [$link, NAME_DELIMITER, '"'.$macro['template']['value'].'"'];
 		}
 
-		$row[] = array_key_exists('template', $macro) ? '&lArr;' : '';
+		$row[] = array_key_exists('template', $macro) ? LARR() : '';
 		$row[] = (new CDiv(array_key_exists('template', $macro) ? $template_macro : null))
 			->setAdaptiveWidth($inherited_width)
 			->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS);
 
 		// Global macro value.
-		$row[] = array_key_exists('global', $macro) ? '&lArr;' : '';
+		$row[] = array_key_exists('global', $macro) ? LARR() : '';
 		$row[] = (new CDiv(array_key_exists('global', $macro) ? '"'.$macro['global']['value'].'"' : null))
 			->setAdaptiveWidth($inherited_width)
 			->addClass(ZBX_STYLE_OVERFLOW_ELLIPSIS);
