@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -161,7 +161,10 @@
 
 			switch ($btn.data('action')) {
 				case 'add':
-					PopUp('popup.mediatype.message', params, null, $btn);
+					PopUp('popup.mediatype.message', params, {
+						dialogue_class: 'modal-popup-medium',
+						trigger_element: this
+					});
 					break;
 
 				case 'edit':
@@ -179,7 +182,10 @@
 						}
 					});
 
-					PopUp('popup.mediatype.message', params, null, $btn);
+					PopUp('popup.mediatype.message', params, {
+						dialogue_class: 'modal-popup-medium',
+						trigger_element: this
+					});
 					break;
 			}
 		});
@@ -237,7 +243,7 @@
 		});
 
 		// Trim spaces on sumbit. Spaces for script parameters should not be trimmed.
-		$('#media_type_form').submit(function() {
+		$('#media-type-form').submit(function() {
 			var maxattempts = $('#maxattempts'),
 				maxsessions_type = $('#maxsessions_type :radio:checked').val(),
 				maxsessions = $('#maxsessions');
