@@ -29,13 +29,13 @@ if ($data['url']['error'] !== null) {
 else {
 	$item = (new CIFrame($data['url']['url'], '100%', '100%', 'auto'))->addClass(ZBX_STYLE_WIDGET_URL);
 
-	if (ZBX_IFRAME_SANDBOX !== false) {
-		$item->setAttribute('sandbox', ZBX_IFRAME_SANDBOX);
+	if ($data['config']['iframe_sandboxing_enabled'] == 1) {
+		$item->setAttribute('sandbox', $data['config']['iframe_sandboxing_exceptions']);
 	}
 }
 
 $output = [
-	'header' => $data['name'],
+	'name' => $data['name'],
 	'body' => $item->toString()
 ];
 
