@@ -97,10 +97,13 @@ $form = (new CForm())
 	->addVar('add', '1')
 	->addVar('media', $options['media'])
 	->addVar('dstfrm', $options['dstfrm'])
-	->setId('media_form')
-	->addItem([
+	->setId('media_form');
+
+// Enable form submitting on Enter.
+$form->addItem((new CSubmitButton(null))->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
+
+$form->addItem([
 		$media_form,
-		(new CInput('submit', 'submit'))->addStyle('display: none;'),
 		(new CTag('script'))
 			->addItem((new CRow([
 				(new CCol((new CTextBox('sendto_emails[#{rowNum}]', ''))
