@@ -280,9 +280,9 @@ class CHttpTest extends CApiService {
 	 * @throws APIException if the input is invalid.
 	 */
 	protected function validateCreate(array &$httptests): void {
-		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['uuid'], ['hostid', 'name']], 'fields' => [
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['hostid', 'name']], 'fields' => [
 			'hostid' =>				['type' => API_ID, 'flags' => API_REQUIRED],
-			'uuid' =>				['type' => API_UUID],
+			'uuid' =>				['type' => API_ANY],
 			'name' =>				['type' => API_STRING_UTF8, 'flags' => API_REQUIRED | API_NOT_EMPTY, 'length' => DB::getFieldLength('httptest', 'name')],
 			'delay' =>				['type' => API_TIME_UNIT, 'flags' => API_NOT_EMPTY | API_ALLOW_USER_MACRO, 'in' => '1:'.SEC_PER_DAY],
 			'retries' =>			['type' => API_INT32, 'in' => '1:10'],
@@ -344,8 +344,13 @@ class CHttpTest extends CApiService {
 			$names_by_hostid[$httptest['hostid']][] = $httptest['name'];
 		}
 
-		$this->checkAndAddUuid($httptests);
-		$this->checkHostPermissions(array_keys($names_by_hostid));
+		$this->checkHostPermissions(array_keys($names_by_hostid), $db_hosts);
+
+		self::validateUuid($httptests, $db_hosts);
+
+		self::addUuid($httptests, $db_hosts);
+
+		self::checkUuidDuplicates($httptests);
 		$this->checkDuplicates($names_by_hostid);
 		$this->validateAuthParameters($httptests, __FUNCTION__);
 		$this->validateSslParameters($httptests, __FUNCTION__);
@@ -353,41 +358,85 @@ class CHttpTest extends CApiService {
 	}
 
 	/**
-	 * Check that only httptests on templates have UUID. Add UUID to all httptests on templates, if it does not exists.
-	 *
-	 * @param array $httptests_to_create
+	 * @param array $httptests
+	 * @param array $db_hosts
 	 *
 	 * @throws APIException
 	 */
-	protected function checkAndAddUuid(array &$httptests_to_create): void {
-		$db_templateids = API::Template()->get([
-			'output' => [],
-			'templateids' => array_column($httptests_to_create, 'hostid'),
-			'preservekeys' => true
-		]);
+	private static function validateUuid(array $httptests, array $db_hosts): void {
+		foreach ($httptests as &$httptest) {
+			$httptest['host_status'] = $db_hosts[$httptest['hostid']]['status'];
+		}
+		unset($httptest);
 
-		foreach ($httptests_to_create as $index => &$httptest) {
-			if (!array_key_exists($httptest['hostid'], $db_templateids) && array_key_exists('uuid', $httptest)) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Invalid parameter "%1$s": %2$s.', '/' . ($index + 1), _s('unexpected parameter "%1$s"', 'uuid'))
-				);
-			}
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_ALLOW_UNEXPECTED, 'uniq' => [['uuid']], 'fields' => [
+			'host_status' =>	['type' => API_ANY],
+			'uuid' =>			['type' => API_MULTIPLE, 'rules' => [
+									['if' => ['field' => 'host_status', 'in' => HOST_STATUS_TEMPLATE], 'type' => API_UUID],
+									['else' => true, 'type' => API_STRING_UTF8, 'in' => DB::getDefault('httptest', 'uuid'), 'unset' => true]
+			]]
+		]];
 
-			if (array_key_exists($httptest['hostid'], $db_templateids) && !array_key_exists('uuid', $httptest)) {
+		if (!CApiInputValidator::validate($api_input_rules, $httptests, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+		}
+	}
+
+	/**
+	 * Add the UUID to those of the given web scenarios that belong to a template and don't have the 'uuid' parameter
+	 * set.
+	 *
+	 * @param array $httptests
+	 * @param array $db_hosts
+	 */
+	private static function addUuid(array &$httptests, array $db_hosts): void {
+		foreach ($httptests as &$httptest) {
+			if ($db_hosts[$httptest['hostid']]['status'] == HOST_STATUS_TEMPLATE
+					&& !array_key_exists('uuid', $httptest)) {
 				$httptest['uuid'] = generateUuidV4();
 			}
 		}
 		unset($httptest);
+	}
 
-		$db_uuid = DB::select('httptest', [
+	/**
+	 * Verify web scenario UUIDs are not repeated.
+	 *
+	 * @param array      $httptests
+	 * @param array|null $db_httptests
+	 *
+	 * @throws APIException
+	 */
+	private static function checkUuidDuplicates(array $httptests, array $db_httptests = null): void {
+		$httptest_indexes = [];
+
+		foreach ($httptests as $i => $httptest) {
+			if (!array_key_exists('uuid', $httptest) || $httptest['uuid'] === '') {
+				continue;
+			}
+
+			if ($db_httptests === null || $httptest['uuid'] !== $db_httptests[$httptest['httptestid']]['uuid']) {
+				$httptest_indexes[$httptest['uuid']] = $i;
+			}
+		}
+
+		if (!$httptest_indexes) {
+			return;
+		}
+
+		$duplicates = DB::select('httptest', [
 			'output' => ['uuid'],
-			'filter' => ['uuid' => array_column($httptests_to_create, 'uuid')],
+			'filter' => [
+				'uuid' => array_keys($httptest_indexes)
+			],
 			'limit' => 1
 		]);
 
-		if ($db_uuid) {
+		if ($duplicates) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('Entry with UUID "%1$s" already exists.', $db_uuid[0]['uuid'])
+				_s('Invalid parameter "%1$s": %2$s.', '/'.($httptest_indexes[$duplicates[0]['uuid']] + 1),
+					_('web scenario with the same UUID already exists')
+				)
 			);
 		}
 	}
@@ -420,7 +469,7 @@ class CHttpTest extends CApiService {
 	 */
 	protected function validateUpdate(array &$httptests, array &$db_httptests = null) {
 		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['httptestid']], 'fields' => [
-			'uuid' => 				['type' => API_UUID],
+			'uuid' => 				['type' => API_ANY],
 			'httptestid' =>			['type' => API_ID, 'flags' => API_REQUIRED],
 			'name' =>				['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('httptest', 'name')],
 			'delay' =>				['type' => API_TIME_UNIT, 'flags' => API_NOT_EMPTY | API_ALLOW_USER_MACRO, 'in' => '1:'.SEC_PER_DAY],
@@ -480,22 +529,27 @@ class CHttpTest extends CApiService {
 
 		// permissions
 		$db_httptests = $this->get([
-			'output' => ['httptestid', 'hostid', 'name', 'delay', 'retries', 'agent', 'http_proxy',
+			'output' => ['uuid', 'httptestid', 'hostid', 'name', 'delay', 'retries', 'agent', 'http_proxy',
 				'status', 'authentication', 'http_user', 'http_password', 'verify_peer', 'verify_host',
 				'ssl_cert_file', 'ssl_key_file', 'ssl_key_password', 'templateid'
 			],
 			'selectSteps' => ['httpstepid', 'name', 'no', 'url', 'timeout', 'posts', 'required',
 				'status_codes', 'follow_redirects', 'retrieve_mode', 'post_type'
 			],
+			'selectHosts' => ['status'],
 			'httptestids' => zbx_objectValues($httptests, 'httptestid'),
 			'editable' => true,
 			'preservekeys' => true
 		]);
 
+		$db_hosts = [];
+
 		foreach ($db_httptests as &$db_httptest) {
 			$db_httptest['headers'] = [];
 			$db_httptest['variables'] = [];
 			$db_httptest['steps'] = zbx_toHash($db_httptest['steps'], 'httpstepid');
+
+			$db_hosts[$db_httptest['hostid']] = $db_httptest['hosts'][0];
 		}
 		unset($db_httptest);
 
@@ -563,6 +617,10 @@ class CHttpTest extends CApiService {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
+		self::validateUuid($httptests, $db_hosts);
+
+		self::checkUuidDuplicates($httptests, $db_httptests);
+
 		// validation
 		if ($names_by_hostid) {
 			$this->checkDuplicates($names_by_hostid);
@@ -664,34 +722,40 @@ class CHttpTest extends CApiService {
 	/**
 	 * Checks if the current user has access to the given hosts and templates.
 	 *
-	 * @param array $hostids  an array of host or template IDs
+	 * @param array      $hostids
+	 * @param array|null $db_hosts
 	 *
-	 * @throws APIException if the user doesn't have write permissions for the given hosts.
+	 * @throws APIException
 	 */
-	private function checkHostPermissions(array $hostids) {
-		if ($hostids) {
-			$count = API::Host()->get([
-				'countOutput' => true,
-				'hostids' => $hostids,
-				'editable' => true
-			]);
+	private function checkHostPermissions(array $hostids, array &$db_hosts = null): void {
+		$db_hosts = API::Host()->get([
+			'output' => ['status'],
+			'hostids' => $hostids,
+			'editable' => true,
+			'preservekeys' => true
+		]);
 
-			if ($count == count($hostids)) {
-				return;
-			}
-
-			$count += API::Template()->get([
-				'countOutput' => true,
-				'templateids' => $hostids,
-				'editable' => true
-			]);
-
-			if ($count != count($hostids)) {
-				self::exception(ZBX_API_ERROR_PERMISSIONS,
-					_('No permissions to referred object or it does not exist!')
-				);
-			}
+		if (count($db_hosts) == count($hostids)) {
+			return;
 		}
+
+		$db_hosts += API::Template()->get([
+			'output' => [],
+			'templateids' => $hostids,
+			'editable' => true,
+			'preservekeys' => true
+		]);
+
+		if (count($db_hosts) != count($hostids)) {
+			self::exception(ZBX_API_ERROR_PERMISSIONS,
+				_('No permissions to referred object or it does not exist!')
+			);
+		}
+
+		foreach ($db_hosts as &$db_host) {
+			$db_host += ['status' => HOST_STATUS_TEMPLATE];
+		}
+		unset($db_host);
 	}
 
 	/**
