@@ -32,4 +32,11 @@ class CDiv extends CTag {
 
 		return $this;
 	}
+
+	public function setAdaptiveWidth($value) {
+		$this->addStyle('max-width: '.$value.'px;');
+		$this->addStyle('width: 100%;');
+
+		return $this;
+	}
 }
