@@ -49,6 +49,15 @@ class CImportValidatorFactory extends CRegistryFactory {
 			},
 			'5.0' => function() use ($format): CXmlValidatorGeneral {
 				return new C50XmlValidator($format);
+			},
+			'5.2' => function() use ($format): CXmlValidatorGeneral {
+				return new C52XmlValidator($format);
+			},
+			'5.4' => function() use ($format): CXmlValidatorGeneral {
+				return new C54XmlValidator($format);
+			},
+			'6.0' => function() use ($format): CXmlValidatorGeneral {
+				return new C60XmlValidator($format);
 			}
 		]);
 	}
