@@ -222,7 +222,7 @@ class CScreenHistory extends CScreenBase {
 						$value = '"'.$value.'"';
 					}
 					elseif ($items[$history_row['itemid']]['value_type'] == ITEM_VALUE_TYPE_FLOAT) {
-						$value = formatFloat($value, null, ZBX_UNITS_ROUNDOFF_UNSUFFIXED);
+						$value = formatFloat($value, ['decimals' => ZBX_UNITS_ROUNDOFF_UNSUFFIXED]);
 					}
 
 					$row = zbx_date2str(DATE_TIME_FORMAT_SECONDS, $history_row['clock']).' '.$history_row['clock'].
@@ -419,7 +419,7 @@ class CScreenHistory extends CScreenBase {
 					$value = $history_row['value'];
 
 					if ($item['value_type'] == ITEM_VALUE_TYPE_FLOAT) {
-						$value = formatFloat($value, null, ZBX_UNITS_ROUNDOFF_UNSUFFIXED);
+						$value = formatFloat($value, ['decimals' => ZBX_UNITS_ROUNDOFF_UNSUFFIXED]);
 					}
 
 					$value = CValueMapHelper::applyValueMap($item['value_type'], $value, $item['valuemap']);
@@ -503,7 +503,7 @@ class CScreenHistory extends CScreenBase {
 						$value = array_key_exists($item['itemid'], $values) ? $values[$item['itemid']] : '';
 
 						if ($item['value_type'] == ITEM_VALUE_TYPE_FLOAT && $value !== '') {
-							$value = formatFloat($value, null, ZBX_UNITS_ROUNDOFF_UNSUFFIXED);
+							$value = formatFloat($value, ['decimals' => ZBX_UNITS_ROUNDOFF_UNSUFFIXED]);
 						}
 
 						$value = CValueMapHelper::applyValueMap($item['value_type'], $value, $item['valuemap']);
