@@ -804,7 +804,7 @@ function convertUnitsRaw(array $options): array {
 	$unit_base = $options['unit_base'];
 
 	if ($unit_base != 1000 && $unit_base != ZBX_KIBIBYTE) {
-		$unit_base = ($units === 'B' || $units === 'Bps') ? ZBX_KIBIBYTE : 1000;
+		$unit_base = isBinaryUnits($units) ? ZBX_KIBIBYTE : 1000;
 	}
 
 	if ($options['power'] === null) {
@@ -1396,7 +1396,7 @@ function zbx_str2links($text) {
 				if ($pos != $start) {
 					$result[] = mb_substr($line, $start, $pos - $start);
 				}
-				$result[] = new CLink(CHtml::encode($match), $match);
+				$result[] = new CLink($match, $match);
 				$start = $pos + mb_strlen($match);
 			}
 		}
@@ -1609,6 +1609,10 @@ function formatFloat(float $number, array $options = []): string {
 * @return float
 */
 function truncateFloat(float $number): float {
+	if (is_infinite($number)) {
+		return $number;
+	}
+
 	return (float) sprintf('%.'.(ZBX_FLOAT_DIG - 1).'E', $number);
 }
 
