@@ -344,7 +344,7 @@ const ZBX_TEXTAREA_COLOR_WIDTH = 96;
 		 * @param {callable}  options.onUpdate     Callback function to execute once color has changed.
 		 */
 		return this.each(function (_, element) {
-			const id = $(element).attr('id');
+			const id = element.id;
 
 			if ($('#lbl_' + id).length) {
 				return;
@@ -360,18 +360,18 @@ const ZBX_TEXTAREA_COLOR_WIDTH = 96;
 				.on('keydown', function (e) {
 					if (e.keyCode == KEY_ENTER || e.keyCode == KEY_SPACE) {
 						e.preventDefault();
-						methods.show(id, e.target);
+						methods.show(element.id, e.target);
 					}
 				})
 				.on('click', function (e) {
-					methods.show(id, e.target);
+					methods.show(element.id, e.target);
 				})
 				.insertAfter(element);
 
 			$(element)
 				.data('use_default', options.use_default)
 				.change(function () {
-					methods.set_color_by_id($(element).attr('id'), this.value);
+					methods.set_color_by_id(element.id, this.value);
 					if (options.onUpdate !== null) {
 						options.onUpdate.call(element, this.value);
 					}
