@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 // Sync with SASS variable: $ui-transition-duration.
 const UI_TRANSITION_DURATION = 300;
 
+const PROFILE_TYPE_INT = 2;
+const PROFILE_TYPE_STR = 3;
+
 // Array indexOf method for javascript<1.6 compatibility
 if (!Array.prototype.indexOf) {
 	Array.prototype.indexOf = function (searchElement) {
@@ -80,7 +83,7 @@ var PageRefresh = {
 
 		if (this.delayLeft < 0 && !overlays_stack.length) {
 			if (ED) {
-				sessionStorage.scrollTop = jQuery(window).scrollTop();
+				sessionStorage.scrollTop = $('.wrapper').scrollTop();
 			}
 
 			location.reload();
@@ -208,7 +211,6 @@ var AudioControl = {
  * Elements with class 'blink' will blink for 'data-seconds-to-blink' seconds
  * If 'data-seconds-to-blink' is omitted, element will blink forever.
  * For elements with class 'blink' and attribute 'data-toggle-class' class will be toggled.
- * @author Konstantin Buravcov
  */
 var jqBlink = {
 	shown: true, // are objects currently shown or hidden?
@@ -254,6 +256,9 @@ var jqBlink = {
  */
 var hintBox = {
 
+	preload_hint_timer: null,
+	show_hint_timer: null,
+
 	/**
 	 * Initialize hint box event handlers.
 	 *
@@ -262,54 +267,180 @@ var hintBox = {
 	 */
 	bindEvents: function () {
 		jQuery(document).on('keydown click mouseenter mouseleave', '[data-hintbox=1]', function (e) {
+			var $target = jQuery(this).hasClass('hint-item')
+				? jQuery(this).siblings('.main-hint')
+				: jQuery(this);
 
-			if (jQuery(this).hasClass('hint-item')) {
-				var target = jQuery(this).siblings('.main-hint');
-			}
-			else {
-				var target = jQuery(this);
+			if (e.type === 'keydown') {
+				if (e.which != 13) {
+					return;
+				}
+
+				var offset = $target.offset(),
+					w = jQuery(window);
+
+				// Emulate a click on the left middle point of the target.
+				e.clientX = offset.left - w.scrollLeft();
+				e.clientY = offset.top - w.scrollTop() + ($target.height() / 2);
+				e.preventDefault();
 			}
 
-			switch (e.type) {
-				case 'mouseenter':
-					hintBox.showHint(e, target[0], target.next('.hint-box').html(), target.data('hintbox-class'), false,
-						target.data('hintbox-style')
-					);
-					break;
+			if ($target.data('hintbox-preload') && $target.next('.hint-box').children().length == 0) {
+				clearTimeout(hintBox.preload_hint_timer);
 
-				case 'mouseleave':
-					hintBox.hideHint(target[0], false);
-					break;
+				// Manually trigger preloaderCloseHandler for the previous preloader.
+				if (jQuery('#hintbox-preloader').length) {
 
-				case 'keydown':
-					if (e.which == 13 && target.data('hintbox-static') == 1) {
-						var offset = target.offset(),
-							w = jQuery(window);
-						// Emulate click on left middle point of link.
-						e.clientX = offset.left - w.scrollLeft();
-						e.clientY = offset.top - w.scrollTop() + (target.height() / 2);
-						e.preventDefault();
-
-						hintBox.showStaticHint(e, target[0], target.data('hintbox-class'), false,
-							target.data('hintbox-style')
-						);
+					// Prevent loading restart on repetitive click and keydown events.
+					if (e.type === 'click' || e.type === 'keydown') {
+						return false;
 					}
-					break;
 
-				case 'click':
-					if (target.data('hintbox-static') == 1) {
-						hintBox.showStaticHint(e, target[0], target.data('hintbox-class'), false,
-							target.data('hintbox-style')
-						);
-					}
-					break;
+					jQuery(document).trigger('click');
+				}
+
+				if (e.type === 'mouseleave') {
+					$target.blur();
+
+					return false;
+				}
+
+				var preloadHintHandler = function() {
+					hintBox.preloadHint(e, $target);
+				}
+
+				if (e.type === 'mouseenter') {
+					hintBox.preload_hint_timer = setTimeout(preloadHintHandler, 400);
+				}
+				else {
+					preloadHintHandler();
+				}
+
+				return false;
 			}
+
+			hintBox.displayHint(e, $target, $target.data('hintbox-delay') !== undefined
+				? $target.data('hintbox-delay')
+				: 400
+			);
+
+			return false;
 		});
 	},
 
+	displayHint: function(e, $target, delay = 0) {
+		clearTimeout(hintBox.show_hint_timer);
+
+		switch (e.handleObj.origType) {
+			case 'mouseenter':
+				var showHintHandler = function() {
+					hintBox.showHint(e, $target[0], $target.next('.hint-box').html(), $target.data('hintbox-class'),
+						false, $target.data('hintbox-style')
+					);
+				}
+
+				if (delay > 0) {
+					hintBox.show_hint_timer = setTimeout(showHintHandler, delay);
+				}
+				else {
+					showHintHandler();
+				}
+				break;
+
+			case 'mouseleave':
+				hintBox.hideHint($target[0], false);
+				$target.blur();
+				break;
+
+			case 'keydown':
+			case 'click':
+				if ($target.data('hintbox-static') == 1) {
+					hintBox.showStaticHint(e, $target[0], $target.data('hintbox-class'), false,
+						$target.data('hintbox-style')
+					);
+				}
+				break;
+		}
+	},
+
+	getHintboxAction: function(hint_type) {
+		switch (hint_type) {
+			case 'eventlist':
+				return 'hintbox.eventlist';
+
+			case 'eventactions':
+				return 'hintbox.actionlist';
+		}
+	},
+
+	preloadHint: function(e, $target) {
+		var url = new Curl('zabbix.php'),
+			data = $target.data('hintbox-preload');
+
+		url.setArgument('action', hintBox.getHintboxAction(data.type));
+
+		var xhr = jQuery.ajax({
+			url: url.getUrl(),
+			method: 'POST',
+			data: data.data,
+			dataType: 'json'
+		});
+
+		var $preloader = hintBox.createPreloader();
+
+		var preloader_timer = setTimeout(function() {
+			$preloader.fadeIn(200);
+			hintBox.positionElement(e, $target[0], $preloader);
+		}, 500);
+
+		addToOverlaysStack($preloader.prop('id'), $target[0], 'preloader', xhr);
+
+		xhr.done(function(resp) {
+			clearTimeout(preloader_timer);
+			overlayPreloaderDestroy($preloader.prop('id'));
+
+			var $hint_box = $target.next('.hint-box').empty();
+
+			if (resp.messages) {
+				$hint_box.append(resp.messages);
+			}
+			if (resp.data) {
+				$hint_box.append(resp.data);
+			}
+
+			hintBox.displayHint(e, $target);
+		});
+
+		jQuery(document)
+			.off('click', hintBox.preloaderCloseHandler)
+			.on('click', {id: $preloader.prop('id')}, hintBox.preloaderCloseHandler);
+	},
+
+	/**
+	 * Create preloader elements for the hint box.
+	 */
+	createPreloader: function() {
+		return jQuery('<div>', {
+			'id': 'hintbox-preloader',
+			'class': 'is-loading hintbox-preloader'
+		})
+			.appendTo($('.wrapper'))
+			.on('click', function(e) {
+				e.stopPropagation();
+			})
+			.hide();
+	},
+
+	/**
+	 * Event handler for the preloader elements destroy.
+	 */
+	preloaderCloseHandler: function(event) {
+		overlayPreloaderDestroy(event.data.id);
+	},
+
 	createBox: function(e, target, hintText, className, isStatic, styles, appendTo) {
 		var hintboxid = hintBox.getUniqueId(),
-			box = jQuery('<div></div>', {'data-hintboxid': hintboxid}).addClass('overlay-dialogue'),
+			box = jQuery('<div>', {'data-hintboxid': hintboxid}).addClass('overlay-dialogue'),
 			appendTo = appendTo || '.wrapper';
 
 		if (styles) {
@@ -331,7 +462,7 @@ var hintBox = {
 		}
 
 		if (!empty(className)) {
-			box.append(jQuery('<div></div>').addClass(className).html(hintText));
+			box.append(jQuery('<div>').addClass(className).html(hintText));
 		}
 		else {
 			box.html(hintText);
@@ -355,13 +486,20 @@ var hintBox = {
 
 		jQuery(appendTo).append(box);
 
-		var removeHandler = function() {
-			hintBox.deleteHint(target);
-		};
+		target.observer = new MutationObserver(() => {
+			const element = target instanceof jQuery ? target[0] : target;
 
-		jQuery(target)
-			.off('remove', removeHandler)
-			.on('remove', removeHandler);
+			if (!isVisible(element)) {
+				hintBox.deleteHint(target);
+			}
+		});
+
+		target.observer.observe(document.body, {
+			attributes: true,
+			attributeFilter: ['style', 'class'],
+			subtree: true,
+			childList: true
+		});
 
 		return box;
 	},
@@ -381,7 +519,7 @@ var hintBox = {
 
 			if (resizeAfterLoad) {
 				hintText.one('load', function(e) {
-					hintBox.positionHint(e, target);
+					hintBox.positionElement(e, target, target.hintBoxItem);
 				});
 			}
 		}
@@ -393,7 +531,7 @@ var hintBox = {
 		}
 
 		target.hintBoxItem = hintBox.createBox(e, target, hintText, className, isStatic, styles);
-		hintBox.positionHint(e, target);
+		hintBox.positionElement(e, target, target.hintBoxItem);
 		target.hintBoxItem.show();
 
 		if (target.isStatic) {
@@ -402,13 +540,13 @@ var hintBox = {
 		}
 	},
 
-	positionHint: function(e, target) {
+	positionElement: function(e, target, $elem) {
 		if (e.clientX) {
 			target.clientX = e.clientX;
 			target.clientY = e.clientY;
 		}
 
-		var $host = target.hintBoxItem.offsetParent(),
+		var $host = $elem.offsetParent(),
 			host_offset = $host.offset(),
 			// Usable area relative to host.
 			host_x_min = $host.scrollLeft(),
@@ -424,15 +562,15 @@ var hintBox = {
 			event_y = target.clientY - host_offset.top + $host.scrollTop(),
 			event_offset = 10,
 			// Hint box width and height.
-			hint_width = target.hintBoxItem.outerWidth(),
-			hint_height = target.hintBoxItem.outerHeight(),
+			hint_width = $elem.outerWidth(),
+			hint_height = $elem.outerHeight(),
 			/*
 				Fix popup width and height since browsers will tend to reduce the size of the popup, if positioned further
 				than the width of window when horizontal scrolling is active.
 			*/
 			css = {
-				width: target.hintBoxItem.width(),
-				height: target.hintBoxItem.height()
+				width: $elem.width(),
+				height: $elem.height()
 			};
 
 		if (event_x + event_offset + hint_width <= host_x_max) {
@@ -461,7 +599,7 @@ var hintBox = {
 			}
 		}
 
-		target.hintBoxItem.css(css);
+		$elem.css(css);
 	},
 
 	hideHint: function(target, hideStatic) {
@@ -484,12 +622,28 @@ var hintBox = {
 			delete target.hintBoxItem;
 
 			if (target.isStatic) {
-				if (jQuery(target).data('return-control') !== 'undefined') {
+				if (jQuery(target).data('return-control') !== undefined) {
 					jQuery(target).data('return-control').focus();
 				}
 				delete target.isStatic;
 			}
 		}
+
+		if (target.observer !== undefined) {
+			target.observer.disconnect();
+
+			delete target.observer;
+		}
+	},
+
+	deleteAll: () => {
+		for (let i = overlays_stack.length - 1; i >= 0; i--) {
+			const overlay = overlays_stack.getById(overlays_stack.stack[i]);
+
+			if (overlay.type === 'hintbox') {
+				hintBox.deleteHint(overlay.element);
+			}
+		}
 	},
 
 	getUniqueId: function() {
@@ -530,14 +684,20 @@ function rm4favorites(object, objectid) {
  * Toggles filter state and updates title and icons accordingly.
  *
  * @param {string} 	idx					User profile index
- * @param {string} 	value_int			Integer value
+ * @param {string} 	value				Value
  * @param {object} 	idx2				An array of IDs
+ * @param {integer} profile_type		Profile type
  */
-function updateUserProfile(idx, value_int, idx2) {
+function updateUserProfile(idx, value, idx2, profile_type = PROFILE_TYPE_INT) {
+	const value_fields = {
+		[PROFILE_TYPE_INT]: 'value_int',
+		[PROFILE_TYPE_STR]: 'value_str'
+	};
+
 	return sendAjaxData('zabbix.php?action=profile.update', {
 		data: {
 			idx: idx,
-			value_int: value_int,
+			[value_fields[profile_type]]: value,
 			idx2: idx2
 		}
 	});
@@ -550,11 +710,11 @@ function changeWidgetState(obj, widgetId, idx) {
 
 	if (css === 'btn-widget-expand') {
 		jQuery('.body', widgetObj).slideUp(50);
-		jQuery('.dashbrd-widget-foot', widgetObj).slideUp(50);
+		jQuery('.dashboard-widget-foot', widgetObj).slideUp(50);
 	}
 	else {
 		jQuery('.body', widgetObj).slideDown(50);
-		jQuery('.dashbrd-widget-foot', widgetObj).slideDown(50);
+		jQuery('.dashboard-widget-foot', widgetObj).slideDown(50);
 
 		state = 1;
 	}
@@ -704,6 +864,7 @@ function getConditionFormula(conditions, evalType) {
 	 * - row					- element row selector
 	 * - add					- add row button selector
 	 * - remove					- remove row button selector
+	 * - rows					- array of rows objects data
 	 * - counter 				- number to start row enumeration from
 	 * - dataCallback			- function to generate the data passed to the template
 	 * - remove_next_sibling	- remove also next element
@@ -726,6 +887,7 @@ function getConditionFormula(conditions, evalType) {
 			disable: '.element-table-disable',
 			counter: null,
 			beforeRow: null,
+			rows: [],
 			dataCallback: function(data) {
 				return {};
 			}
@@ -763,9 +925,52 @@ function getConditionFormula(conditions, evalType) {
 				// disable the parent row
 				disableRow($(this).closest(options.row));
 			});
+
+			if (typeof options.rows === 'object') {
+				var before_row = (options['beforeRow'] !== null)
+					? $(options['beforeRow'], table)
+					: $(options.add, table).closest('tr');
+
+				initRows(table, before_row, options);
+			}
 		});
 	};
 
+	/**
+	 * Renders options.rows array as HTML rows during initialization.
+	 *
+	 * @param {jQuery} table       Table jquery node.
+	 * @param {jQuery} before_row  Rendered rows will be inserted before this node.
+	 * @param {object} options     Object with options.
+	 */
+	function initRows(table, before_row, options) {
+		var template = new Template($(options.template).html()),
+			counter = table.data('dynamicRows').counter,
+			$row;
+
+		options.rows.forEach((data) => {
+			data.rowNum = counter;
+			$row = $(template.evaluate($.extend(data, options.dataCallback(data))));
+
+			for (const name in data) {
+				// Set 'z-select' value.
+				$row
+					.find(`z-select[name$="[${counter}][${name}]"]`)
+					.val(data[name]);
+
+				// Set 'radio' value.
+				$row
+					.find(`[type="radio"][name$="[${counter}][${name}]"][value="${$.escapeSelector(data[name])}"]`)
+					.attr('checked', 'checked');
+			}
+
+			before_row.before($row);
+			++counter;
+		});
+
+		table.data('dynamicRows').counter = counter;
+	}
+
 	/**
 	 * Adds a row before the given row.
 	 *
@@ -809,6 +1014,7 @@ function getConditionFormula(conditions, evalType) {
 	 * @param {jQuery} row
 	 */
 	function disableRow(row) {
+		row.find('textarea').prop('readonly', true);
 		row.find('input').prop('readonly', true);
 		row.find('button').prop('disabled', true);
 	}
@@ -882,7 +1088,7 @@ jQuery(function ($) {
 	};
 
 	if (ED && typeof sessionStorage.scrollTop !== 'undefined') {
-		$(window).scrollTop(sessionStorage.scrollTop);
+		$('.wrapper').scrollTop(sessionStorage.scrollTop);
 		sessionStorage.removeItem('scrollTop');
 	}
 });
