@@ -26,7 +26,6 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of trigger prototypes');
 $page['file'] = 'trigger_prototypes.php';
-$page['scripts'] = ['multiselect.js', 'textareaflexible.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -36,6 +35,7 @@ $fields = [
 	'triggerid' =>								[T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		'(isset({form}) && ({form} == "update"))'],
 	'type' =>									[T_ZBX_INT, O_OPT, null,	IN('0,1'),	null],
 	'description' =>							[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({add}) || isset({update})', _('Name')],
+	'event_name' =>								[T_ZBX_STR, O_OPT, null,	null,		'isset({add}) || isset({update})'],
 	'opdata' =>									[T_ZBX_STR, O_OPT, null,	null,		'isset({add}) || isset({update})'],
 	'expression' =>								[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({add}) || isset({update})', _('Expression')],
 	'recovery_expression' =>					[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'(isset({add}) || isset({update})) && isset({recovery_mode}) && {recovery_mode} == '.ZBX_RECOVERY_MODE_RECOVERY_EXPRESSION.'', _('Recovery expression')],
@@ -57,10 +57,6 @@ $fields = [
 	'new_dependency' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID.NOT_ZERO, 'isset({add_dependency})'],
 	'g_triggerid' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID,		null],
 	'tags' =>									[T_ZBX_STR, O_OPT, P_ONLY_TD_ARRAY,	null,		null],
-	'mass_update_tags'	=>						[T_ZBX_INT, O_OPT, null,
-													IN([ZBX_ACTION_ADD, ZBX_ACTION_REPLACE, ZBX_ACTION_REMOVE]),
-													null
-												],
 	'show_inherited_tags' =>					[T_ZBX_INT, O_OPT, null,	IN([0,1]),	null],
 	'manual_close' =>							[T_ZBX_INT, O_OPT, null,
 													IN([ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED,
@@ -68,11 +64,12 @@ $fields = [
 													]),
 													null
 												],
+	'context' =>								[T_ZBX_STR, O_MAND, P_SYS,	IN('"host", "template"'),	null],
 	// actions
 	'action' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT,
 													IN('"triggerprototype.massdelete","triggerprototype.massdisable",'.
-														'"triggerprototype.massenable","triggerprototype.massupdate",'.
-														'"triggerprototype.massupdateform"'
+														'"triggerprototype.massenable","triggerprototype.discover.enable",'.
+														'"triggerprototype.discover.disable"'
 													),
 													null
 												],
@@ -98,11 +95,11 @@ $fields = [
 	'clone' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'add' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'update' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
-	'massupdate' =>								[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'delete' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'cancel' =>									[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form' =>									[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form_refresh' =>							[T_ZBX_INT, O_OPT, P_SYS,	null,		null],
+	'backurl' =>								[T_ZBX_STR, O_OPT, null,	null,		null],
 	// sort and sortorder
 	'sort' =>									[T_ZBX_STR, O_OPT, P_SYS, IN('"description","priority","status","discover"'),		null],
 	'sortorder' =>								[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
@@ -136,6 +133,10 @@ if (hasRequest('triggerid')) {
 	}
 }
 
+// Validate backurl.
+if (hasRequest('backurl') && !CHtmlUrlValidator::validateSameSite(getRequest('backurl'))) {
+	access_deny();
+}
 
 $tags = getRequest('tags', []);
 foreach ($tags as $key => $tag) {
@@ -202,6 +203,7 @@ if (hasRequest('clone') && hasRequest('triggerid')) {
 elseif (hasRequest('add') || hasRequest('update')) {
 	$dependencies = zbx_toObject(getRequest('dependencies', []), 'triggerid');
 	$description = getRequest('description', '');
+	$event_name = getRequest('event_name', '');
 	$opdata = getRequest('opdata', '');
 	$expression = getRequest('expression', '');
 	$recovery_mode = getRequest('recovery_mode', ZBX_RECOVERY_MODE_EXPRESSION);
@@ -219,6 +221,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 	if (hasRequest('add')) {
 		$trigger_prototype = [
 			'description' => $description,
+			'event_name' => $event_name,
 			'opdata' => $opdata,
 			'expression' => $expression,
 			'recovery_mode' => $recovery_mode,
@@ -247,13 +250,18 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 		$result = (bool) API::TriggerPrototype()->create($trigger_prototype);
 
-		show_messages($result, _('Trigger prototype added'), _('Cannot add trigger prototype'));
+		if ($result) {
+			CMessageHelper::setSuccessTitle(_('Trigger prototype added'));
+		}
+		else {
+			CMessageHelper::setErrorTitle(_('Cannot add trigger prototype'));
+		}
 	}
 	else {
 		$db_trigger_prototypes = API::TriggerPrototype()->get([
 			'output' => ['expression', 'description', 'url', 'status', 'priority', 'comments', 'templateid', 'type',
 				'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag', 'manual_close', 'opdata',
-				'discover'
+				'discover', 'event_name'
 			],
 			'selectDependencies' => ['triggerid'],
 			'selectTags' => ['tag', 'value'],
@@ -272,6 +280,9 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			if ($db_trigger_prototype['description'] !== $description) {
 				$trigger_prototype['description'] = $description;
 			}
+			if ($db_trigger_prototype['event_name'] !== $event_name) {
+				$trigger_prototype['event_name'] = $event_name;
+			}
 			if ($db_trigger_prototype['opdata'] !== $opdata) {
 				$trigger_prototype['opdata'] = $opdata;
 			}
@@ -347,22 +358,40 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			$result = true;
 		}
 
-		show_messages($result, _('Trigger prototype updated'), _('Cannot update trigger prototype'));
+		if ($result) {
+			CMessageHelper::setSuccessTitle(_('Trigger prototype updated'));
+		}
+		else {
+			CMessageHelper::setErrorTitle(_('Cannot update trigger prototype'));
+		}
 	}
 
 	if ($result) {
 		unset($_REQUEST['form']);
 		uncheckTableRows(getRequest('parent_discoveryid'));
+
+		if (hasRequest('backurl')) {
+			$response = new CControllerResponseRedirect(getRequest('backurl'));
+			$response->redirect();
+		}
 	}
 }
 elseif (hasRequest('delete') && hasRequest('triggerid')) {
 	$result = API::TriggerPrototype()->delete([getRequest('triggerid')]);
 
 	if ($result) {
+		CMessageHelper::setSuccessTitle(_('Trigger prototype deleted'));
 		unset($_REQUEST['form'], $_REQUEST['triggerid']);
 		uncheckTableRows(getRequest('parent_discoveryid'));
+
+		if (hasRequest('backurl')) {
+			$response = new CControllerResponseRedirect(getRequest('backurl'));
+			$response->redirect();
+		}
+	}
+	else {
+		CMessageHelper::setErrorTitle(_('Cannot delete trigger prototype'));
 	}
-	show_messages($result, _('Trigger prototype deleted'), _('Cannot delete trigger prototype'));
 }
 elseif (hasRequest('add_dependency') && hasRequest('new_dependency')) {
 	if (!hasRequest('dependencies')) {
@@ -374,104 +403,6 @@ elseif (hasRequest('add_dependency') && hasRequest('new_dependency')) {
 		}
 	}
 }
-elseif (hasRequest('action') && getRequest('action') === 'triggerprototype.massupdate'
-		&& hasRequest('massupdate') && hasRequest('g_triggerid')) {
-	$result = true;
-	$visible = getRequest('visible', []);
-
-	if ($visible) {
-		$triggerids = getRequest('g_triggerid');
-		$triggers_to_update = [];
-
-		$options = [
-			'output' => ['triggerid', 'templateid'],
-			'triggerids' => $triggerids,
-			'preservekeys' => true
-		];
-
-		if (array_key_exists('tags', $visible)) {
-			$mass_update_tags = getRequest('mass_update_tags', ZBX_ACTION_ADD);
-
-			if ($mass_update_tags == ZBX_ACTION_ADD || $mass_update_tags == ZBX_ACTION_REMOVE) {
-				$options['selectTags'] = ['tag', 'value'];
-			}
-
-			$unique_tags = [];
-
-			foreach ($tags as $tag) {
-				$unique_tags[$tag['tag'].':'.$tag['value']] = $tag;
-			}
-
-			$tags = array_values($unique_tags);
-		}
-
-		$triggers = API::TriggerPrototype()->get($options);
-
-		if ($triggers) {
-			foreach ($triggerids as $triggerid) {
-				if (array_key_exists($triggerid, $triggers)) {
-					$trigger = ['triggerid' => $triggerid];
-
-					if (array_key_exists('priority', $visible)) {
-						$trigger['priority'] = getRequest('priority');
-					}
-
-					if (array_key_exists('dependencies', $visible)) {
-						$trigger['dependencies'] = zbx_toObject(getRequest('dependencies', []), 'triggerid');
-					}
-
-					if (array_key_exists('tags', $visible)) {
-						if ($tags && $mass_update_tags == ZBX_ACTION_ADD) {
-							$unique_tags = [];
-
-							foreach (array_merge($triggers[$triggerid]['tags'], $tags) as $tag) {
-								$unique_tags[$tag['tag'].':'.$tag['value']] = $tag;
-							}
-
-							$trigger['tags'] = array_values($unique_tags);
-						}
-						elseif ($mass_update_tags == ZBX_ACTION_REPLACE) {
-							$trigger['tags'] = $tags;
-						}
-						elseif ($tags && $mass_update_tags == ZBX_ACTION_REMOVE) {
-							$diff_tags = [];
-
-							foreach ($triggers[$triggerid]['tags'] as $a) {
-								foreach ($tags as $b) {
-									if ($a['tag'] === $b['tag'] && $a['value'] === $b['value']) {
-										continue 2;
-									}
-								}
-
-								$diff_tags[] = $a;
-							}
-
-							$trigger['tags'] = $diff_tags;
-						}
-					}
-
-					if ($triggers[$triggerid]['templateid'] == 0 && array_key_exists('manual_close', $visible)) {
-						$trigger['manual_close'] = getRequest('manual_close');
-					}
-
-					if (array_key_exists('discover', $visible)) {
-						$trigger['discover'] = getRequest('discover');
-					}
-
-					$triggers_to_update[] = $trigger;
-				}
-			}
-		}
-
-		$result = (bool) API::TriggerPrototype()->update($triggers_to_update);
-	}
-
-	if ($result) {
-		unset($_REQUEST['massupdate'], $_REQUEST['form'], $_REQUEST['g_triggerid']);
-		uncheckTableRows(getRequest('parent_discoveryid'));
-	}
-	show_messages($result, _('Trigger prototypes updated'), _('Cannot update trigger prototypes'));
-}
 elseif (getRequest('action') && str_in_array(getRequest('action'), ['triggerprototype.massenable', 'triggerprototype.massdisable']) && hasRequest('g_triggerid')) {
 	$status = (getRequest('action') === 'triggerprototype.massenable')
 		? TRIGGER_STATUS_ENABLED
@@ -518,35 +449,52 @@ elseif (hasRequest('action') && getRequest('action') === 'triggerprototype.massd
 	}
 	show_messages($result, _('Trigger prototypes deleted'), _('Cannot delete trigger prototypes'));
 }
+elseif (getRequest('action') && hasRequest('g_triggerid')
+		&& in_array(getRequest('action'), ['triggerprototype.discover.enable', 'triggerprototype.discover.disable'])) {
+	$triggerids = getRequest('g_triggerid');
+	$discover = (getRequest('action') === 'triggerprototype.discover.enable')
+		? TRIGGER_DISCOVER
+		: TRIGGER_NO_DISCOVER;
+	$update = [];
 
-if (hasRequest('action') && getRequest('action') !== 'triggerprototype.massupdateform' && hasRequest('g_triggerid')
-		&& !$result) {
-	$triggerPrototypes = API::TriggerPrototype()->get([
-			'output' => [],
-			'triggerids' => getRequest('g_triggerid'),
-			'editable' => true
-		]);
+	// Get requested triggers with permission check.
+	$db_trigger_prototypes = API::TriggerPrototype()->get([
+		'output' => [],
+		'triggerids' => getRequest('g_triggerid'),
+		'editable' => true
+	]);
 
-	uncheckTableRows(getRequest('parent_discoveryid'), zbx_objectValues($triggerPrototypes, 'triggerid'));
+	if ($db_trigger_prototypes) {
+		foreach ($db_trigger_prototypes as $db_trigger_prototype) {
+			$update[] = [
+				'triggerid' => $db_trigger_prototype['triggerid'],
+				'discover' => $discover
+			];
+		}
+
+		$result = API::TriggerPrototype()->update($update);
+	}
+	else {
+		$result = true;
+	}
+
+	if ($result) {
+		uncheckTableRows(getRequest('parent_discoveryid'));
+	}
+
+	$updated = count($update);
+
+	$messageSuccess = _n('Trigger prototype updated', 'Trigger prototypes updated', $updated);
+	$messageFailed = _n('Cannot update trigger prototype', 'Cannot update trigger prototypes', $updated);
+
+	show_messages($result, $messageSuccess, $messageFailed);
 }
 
-$config = select_config();
-
 /*
  * Display
  */
-if ((getRequest('action') === 'triggerprototype.massupdateform' || hasRequest('massupdate'))
-		&& hasRequest('g_triggerid')) {
-	$data = getTriggerMassupdateFormData();
-	$data['action'] = 'triggerprototype.massupdate';
-	$data['hostid'] = $discoveryRule['hostid'];
-
-	// Render view.
-	echo (new CView('configuration.trigger.prototype.massupdate', $data))->getOutput();
-}
-elseif (isset($_REQUEST['form'])) {
+if (isset($_REQUEST['form'])) {
 	$data = getTriggerFormData([
-		'config' => $config,
 		'form' => getRequest('form'),
 		'form_refresh' => getRequest('form_refresh', 0),
 		'parent_discoveryid' => getRequest('parent_discoveryid'),
@@ -559,6 +507,7 @@ elseif (isset($_REQUEST['form'])) {
 		'recovery_expr_temp' => getRequest('recovery_expr_temp', ''),
 		'recovery_mode' => getRequest('recovery_mode', ZBX_RECOVERY_MODE_EXPRESSION),
 		'description' => getRequest('description', ''),
+		'event_name' => getRequest('event_name', ''),
 		'opdata' => getRequest('opdata', ''),
 		'type' => getRequest('type', 0),
 		'priority' => getRequest('priority', TRIGGER_SEVERITY_NOT_CLASSIFIED),
@@ -578,18 +527,22 @@ elseif (isset($_REQUEST['form'])) {
 		'show_inherited_tags' => getRequest('show_inherited_tags', 0),
 		'correlation_mode' => getRequest('correlation_mode', ZBX_TRIGGER_CORRELATION_NONE),
 		'correlation_tag' => getRequest('correlation_tag', ''),
-		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED)
+		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED),
+		'context' => getRequest('context'),
+		'backurl' => getRequest('backurl')
 	]);
 
 	// render view
 	echo (new CView('configuration.trigger.prototype.edit', $data))->getOutput();
 }
 else {
-	$sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'description'));
-	$sortOrder = getRequest('sortorder', CProfile::get('web.'.$page['file'].'.sortorder', ZBX_SORT_UP));
+	$prefix = (getRequest('context') === 'host') ? 'web.hosts.' : 'web.templates.';
 
-	CProfile::update('web.'.$page['file'].'.sort', $sortField, PROFILE_TYPE_STR);
-	CProfile::update('web.'.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR);
+	$sortField = getRequest('sort', CProfile::get($prefix.$page['file'].'.sort', 'description'));
+	$sortOrder = getRequest('sortorder', CProfile::get($prefix.$page['file'].'.sortorder', ZBX_SORT_UP));
+
+	CProfile::update($prefix.$page['file'].'.sort', $sortField, PROFILE_TYPE_STR);
+	CProfile::update($prefix.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR);
 
 	$data = [
 		'parent_discoveryid' => getRequest('parent_discoveryid'),
@@ -598,8 +551,8 @@ else {
 		'triggers' => [],
 		'sort' => $sortField,
 		'sortorder' => $sortOrder,
-		'config' => $config,
-		'dependencyTriggers' => []
+		'dependencyTriggers' => [],
+		'context' => getRequest('context')
 	];
 
 	// get triggers
@@ -608,7 +561,7 @@ else {
 		'output' => ['triggerid', $sortField],
 		'discoveryids' => $data['parent_discoveryid'],
 		'sortfield' => $sortField,
-		'limit' => $config['search_limit'] + 1
+		'limit' => CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1
 	];
 	$data['triggers'] = API::TriggerPrototype()->get($options);
 
@@ -628,7 +581,9 @@ else {
 	CPagerHelper::savePage($page['file'], $page_num);
 
 	$data['paging'] = CPagerHelper::paginate($page_num, $data['triggers'], $sortOrder,
-		(new CUrl('trigger_prototypes.php'))->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+		(new CUrl('trigger_prototypes.php'))
+			->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+			->setArgument('context', $data['context'])
 	);
 
 	$data['triggers'] = API::TriggerPrototype()->get([
@@ -688,6 +643,7 @@ else {
 	}
 
 	$data['parent_templates'] = getTriggerParentTemplates($data['triggers'], ZBX_FLAG_DISCOVERY_PROTOTYPE);
+	$data['allowed_ui_conf_templates'] = CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES);
 
 	// Render view.
 	echo (new CView('configuration.trigger.prototype.list', $data))->getOutput();
