@@ -26,7 +26,7 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of triggers');
 $page['file'] = 'triggers.php';
-$page['scripts'] = ['multiselect.js', 'textareaflexible.js'];
+$page['scripts'] = ['class.tagfilteritem.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -43,6 +43,7 @@ $fields = [
 	'copy_mode' =>								[T_ZBX_INT, O_OPT, P_SYS,	IN('0'),		null],
 	'type' =>									[T_ZBX_INT, O_OPT, null,	IN('0,1'),		null],
 	'description' =>							[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'isset({add}) || isset({update})', _('Name')],
+	'event_name' =>								[T_ZBX_STR, O_OPT, null,	null,			'isset({add}) || isset({update})'],
 	'opdata' =>									[T_ZBX_STR, O_OPT, null,	null,			'isset({add}) || isset({update})'],
 	'expression' =>								[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'isset({add}) || isset({update})', _('Expression')],
 	'recovery_expression' =>					[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'(isset({add}) || isset({update})) && isset({recovery_mode}) && {recovery_mode} == '.ZBX_RECOVERY_MODE_RECOVERY_EXPRESSION.'', _('Recovery expression')],
@@ -65,10 +66,6 @@ $fields = [
 	'copy_targetids' =>							[T_ZBX_INT, O_OPT, P_ONLY_ARRAY,	DB_ID,			null],
 	'visible' =>								[T_ZBX_STR, O_OPT, P_ONLY_ARRAY,	null,			null],
 	'tags' =>									[T_ZBX_STR, O_OPT, P_ONLY_TD_ARRAY,	null,			null],
-	'mass_update_tags'	=>						[T_ZBX_INT, O_OPT, null,
-													IN([ZBX_ACTION_ADD, ZBX_ACTION_REPLACE, ZBX_ACTION_REMOVE]),
-													null
-												],
 	'show_inherited_tags' =>					[T_ZBX_INT, O_OPT, null,	IN([0,1]),		null],
 	'manual_close' =>							[T_ZBX_INT, O_OPT, null,
 													IN([ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED,
@@ -76,6 +73,7 @@ $fields = [
 													]),
 													null
 												],
+	'context' =>								[T_ZBX_STR, O_MAND, P_SYS,	IN('"host", "template"'),	null],
 	// Filter related fields.
 	'filter_set' =>								[T_ZBX_STR, O_OPT, P_SYS,	null,			null],
 	'filter_rst' =>								[T_ZBX_STR, O_OPT, P_SYS,	null,			null],
@@ -109,7 +107,7 @@ $fields = [
 	// Action related fields.
 	'action' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT,
 													IN('"trigger.masscopyto","trigger.massdelete","trigger.massdisable",'.
-														'"trigger.massenable","trigger.massupdate","trigger.massupdateform"'
+														'"trigger.massenable"'
 													),
 													null
 												],
@@ -134,12 +132,12 @@ $fields = [
 	'clone' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'add' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'update' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
-	'massupdate' =>								[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'delete' =>									[T_ZBX_STR, O_OPT, P_SYS|P_ACT, null,	null],
 	'cancel' =>									[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form' =>									[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form_refresh' =>							[T_ZBX_INT, O_OPT, P_SYS,	null,		null],
 	'checkbox_hash' =>							[T_ZBX_STR, O_OPT, null,	null,		null],
+	'backurl' =>								[T_ZBX_STR, O_OPT, null,	null,		null],
 	// Sort and sortorder.
 	'sort' =>									[T_ZBX_STR, O_OPT, P_SYS, IN('"description","priority","status"'),		null],
 	'sortorder' =>								[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
@@ -186,16 +184,19 @@ if (getRequest('hostid') && !isWritableHostTemplates([getRequest('hostid')])) {
 	access_deny();
 }
 
+// Validate backurl.
+if (hasRequest('backurl') && !CHtmlUrlValidator::validateSameSite(getRequest('backurl'))) {
+	access_deny();
+}
+
 $tags = getRequest('tags', []);
+
+// Unset empty and inherited tags.
 foreach ($tags as $key => $tag) {
-	// remove empty new tag lines
 	if ($tag['tag'] === '' && $tag['value'] === '') {
 		unset($tags[$key]);
-		continue;
 	}
-
-	// remove inherited tags
-	if (array_key_exists('type', $tag) && !($tag['type'] & ZBX_PROPERTY_OWN)) {
+	elseif (array_key_exists('type', $tag) && !($tag['type'] & ZBX_PROPERTY_OWN)) {
 		unset($tags[$key]);
 	}
 	else {
@@ -206,6 +207,12 @@ foreach ($tags as $key => $tag) {
 /*
  * Actions
  */
+$prefix = (getRequest('context') === 'host') ? 'web.hosts.' : 'web.templates.';
+$filter_hostids = getRequest('filter_set')
+	? getRequest('filter_hostids', [])
+	: CProfile::getArray($prefix.'triggers.filter_hostids', []);
+$checkbox_hash = crc32(implode('', $filter_hostids));
+
 $expression_action = '';
 if (hasRequest('add_expression')) {
 	$_REQUEST['expression'] = getRequest('expr_temp');
@@ -251,6 +258,7 @@ if (hasRequest('clone') && hasRequest('triggerid')) {
 elseif (hasRequest('add') || hasRequest('update')) {
 	$dependencies = zbx_toObject(getRequest('dependencies', []), 'triggerid');
 	$description = getRequest('description', '');
+	$event_name = getRequest('event_name', '');
 	$opdata = getRequest('opdata', '');
 	$expression = getRequest('expression', '');
 	$recovery_mode = getRequest('recovery_mode', ZBX_RECOVERY_MODE_EXPRESSION);
@@ -267,6 +275,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 	if (hasRequest('add')) {
 		$trigger = [
 			'description' => $description,
+			'event_name' => $event_name,
 			'opdata' => $opdata,
 			'expression' => $expression,
 			'recovery_mode' => $recovery_mode,
@@ -296,13 +305,18 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 		$result = (bool) API::Trigger()->create($trigger);
 
-		show_messages($result, _('Trigger added'), _('Cannot add trigger'));
+		if ($result) {
+			CMessageHelper::setSuccessTitle(_('Trigger added'));
+		}
+		else {
+			CMessageHelper::setErrorTitle(_('Cannot add trigger'));
+		}
 	}
 	else {
 		$db_triggers = API::Trigger()->get([
 			'output' => ['expression', 'description', 'url', 'status', 'priority', 'comments', 'templateid', 'type',
 				'flags', 'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag', 'manual_close',
-				'opdata'
+				'opdata', 'event_name'
 			],
 			'selectDependencies' => ['triggerid'],
 			'selectTags' => ['tag', 'value'],
@@ -322,6 +336,9 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				if ($db_trigger['description'] !== $description) {
 					$trigger['description'] = $description;
 				}
+				if ($db_trigger['event_name'] !== $event_name) {
+					$trigger['event_name'] = $event_name;
+				}
 				if ($db_trigger['opdata'] !== $opdata) {
 					$trigger['opdata'] = $opdata;
 				}
@@ -398,22 +415,40 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			$result = true;
 		}
 
-		show_messages($result, _('Trigger updated'), _('Cannot update trigger'));
+		if ($result) {
+			CMessageHelper::setSuccessTitle(_('Trigger updated'));
+		}
+		else {
+			CMessageHelper::setErrorTitle(_('Cannot update trigger'));
+		}
 	}
 
 	if ($result) {
 		unset($_REQUEST['form']);
 		uncheckTableRows(getRequest('checkbox_hash'));
+
+		if (hasRequest('backurl')) {
+			$response = new CControllerResponseRedirect(getRequest('backurl'));
+			$response->redirect();
+		}
 	}
 }
 elseif (isset($_REQUEST['delete']) && isset($_REQUEST['triggerid'])) {
 	$result = API::Trigger()->delete([getRequest('triggerid')]);
 
 	if ($result) {
+		CMessageHelper::setSuccessTitle(_('Trigger deleted'));
 		unset($_REQUEST['form'], $_REQUEST['triggerid']);
 		uncheckTableRows(getRequest('checkbox_hash'));
+
+		if (hasRequest('backurl')) {
+			$response = new CControllerResponseRedirect(getRequest('backurl'));
+			$response->redirect();
+		}
+	}
+	else {
+		CMessageHelper::setErrorTitle(_('Cannot delete trigger'));
 	}
-	show_messages($result, _('Trigger deleted'), _('Cannot delete trigger'));
 }
 elseif (isset($_REQUEST['add_dependency']) && isset($_REQUEST['new_dependency'])) {
 	if (!isset($_REQUEST['dependencies'])) {
@@ -426,100 +461,6 @@ elseif (isset($_REQUEST['add_dependency']) && isset($_REQUEST['new_dependency'])
 		}
 	}
 }
-elseif (hasRequest('action') && getRequest('action') === 'trigger.massupdate'
-		&& hasRequest('massupdate') && hasRequest('g_triggerid')) {
-	$result = true;
-	$visible = getRequest('visible', []);
-
-	if ($visible) {
-		$triggerids = getRequest('g_triggerid');
-		$triggers_to_update = [];
-
-		$options = [
-			'output' => ['triggerid', 'templateid'],
-			'triggerids' => $triggerids,
-			'filter' => ['flags' => ZBX_FLAG_DISCOVERY_NORMAL],
-			'preservekeys' => true
-		];
-
-		if (array_key_exists('tags', $visible)) {
-			$mass_update_tags = getRequest('mass_update_tags', ZBX_ACTION_ADD);
-
-			if ($mass_update_tags == ZBX_ACTION_ADD || $mass_update_tags == ZBX_ACTION_REMOVE) {
-				$options['selectTags'] = ['tag', 'value'];
-			}
-
-			$unique_tags = [];
-
-			foreach ($tags as $tag) {
-				$unique_tags[$tag['tag'].':'.$tag['value']] = $tag;
-			}
-
-			$tags = array_values($unique_tags);
-		}
-
-		$triggers = API::Trigger()->get($options);
-
-		if ($triggers) {
-			foreach ($triggerids as $triggerid) {
-				if (array_key_exists($triggerid, $triggers)) {
-					$trigger = ['triggerid' => $triggerid];
-
-					if (array_key_exists('priority', $visible)) {
-						$trigger['priority'] = getRequest('priority');
-					}
-					if (array_key_exists('dependencies', $visible)) {
-						$trigger['dependencies'] = zbx_toObject(getRequest('dependencies', []), 'triggerid');
-					}
-					if (array_key_exists('tags', $visible)) {
-						if ($tags && $mass_update_tags == ZBX_ACTION_ADD) {
-							$unique_tags = [];
-
-							foreach (array_merge($triggers[$triggerid]['tags'], $tags) as $tag) {
-								$unique_tags[$tag['tag'].':'.$tag['value']] = $tag;
-							}
-
-							$trigger['tags'] = array_values($unique_tags);
-						}
-						elseif ($mass_update_tags == ZBX_ACTION_REPLACE) {
-							$trigger['tags'] = $tags;
-						}
-						elseif ($tags && $mass_update_tags == ZBX_ACTION_REMOVE) {
-							$diff_tags = [];
-
-							foreach ($triggers[$triggerid]['tags'] as $a) {
-								foreach ($tags as $b) {
-									if ($a['tag'] === $b['tag'] && $a['value'] === $b['value']) {
-										continue 2;
-									}
-								}
-
-								$diff_tags[] = $a;
-							}
-
-							$trigger['tags'] = $diff_tags;
-						}
-					}
-					if ($triggers[$triggerid]['templateid'] == 0 && array_key_exists('manual_close', $visible)) {
-						$trigger['manual_close'] = getRequest('manual_close');
-					}
-
-					$triggers_to_update[] = $trigger;
-				}
-			}
-		}
-
-		if ($triggers_to_update) {
-			$result = (bool) API::Trigger()->update($triggers_to_update);
-		}
-	}
-
-	if ($result) {
-		unset($_REQUEST['form'], $_REQUEST['g_triggerid']);
-		uncheckTableRows(getRequest('checkbox_hash'));
-	}
-	show_messages($result, _('Trigger updated'), _('Cannot update trigger'));
-}
 elseif (hasRequest('action') && str_in_array(getRequest('action'), ['trigger.massenable', 'trigger.massdisable']) && hasRequest('g_triggerid')) {
 	$enable = (getRequest('action') === 'trigger.massenable');
 	$status = $enable ? TRIGGER_STATUS_ENABLED : TRIGGER_STATUS_DISABLED;
@@ -555,7 +496,7 @@ elseif (hasRequest('action') && str_in_array(getRequest('action'), ['trigger.mas
 		: _n('Cannot disable trigger', 'Cannot disable triggers', $updated);
 
 	if ($result) {
-		uncheckTableRows(getRequest('checkbox_hash'));
+		$filter_hostids ? uncheckTableRows($checkbox_hash) : uncheckTableRows();
 		unset($_REQUEST['g_triggerid']);
 	}
 
@@ -588,7 +529,7 @@ elseif (hasRequest('action') && getRequest('action') === 'trigger.masscopyto' &&
 
 		DBstart();
 
-		$result = copyTriggersToHosts(getRequest('g_triggerid'), $hosts_ids, getRequest('hostid'));
+		$result = copyTriggersToHosts($hosts_ids, getRequest('hostid'), getRequest('g_triggerid'));
 		$result = DBend($result);
 
 		$triggers_count = count(getRequest('g_triggerid'));
@@ -611,27 +552,17 @@ elseif (hasRequest('action') && getRequest('action') === 'trigger.massdelete' &&
 	$result = API::Trigger()->delete(getRequest('g_triggerid'));
 
 	if ($result) {
-		uncheckTableRows(getRequest('checkbox_hash'));
+		$filter_hostids ? uncheckTableRows($checkbox_hash) : uncheckTableRows();
 	}
 
 	show_messages($result, _('Triggers deleted'), _('Cannot delete triggers'));
 }
 
-$config = select_config();
-
 /*
  * Display
  */
-if ((getRequest('action') === 'trigger.massupdateform' || hasRequest('massupdate')) && hasRequest('g_triggerid')) {
-	$data = getTriggerMassupdateFormData();
-	$data['action'] = 'trigger.massupdate';
-
-	// render view
-	echo (new CView('configuration.triggers.massupdate', $data))->getOutput();
-}
-elseif (isset($_REQUEST['form'])) {
+if (isset($_REQUEST['form'])) {
 	$data = [
-		'config' => $config,
 		'form' => getRequest('form'),
 		'form_refresh' => getRequest('form_refresh', 0),
 		'parent_discoveryid' => null,
@@ -644,6 +575,7 @@ elseif (isset($_REQUEST['form'])) {
 		'recovery_expr_temp' => getRequest('recovery_expr_temp', ''),
 		'recovery_mode' => getRequest('recovery_mode', 0),
 		'description' => getRequest('description', ''),
+		'event_name' => getRequest('event_name', ''),
 		'opdata' => getRequest('opdata', ''),
 		'type' => getRequest('type', 0),
 		'priority' => getRequest('priority', TRIGGER_SEVERITY_NOT_CLASSIFIED),
@@ -662,7 +594,9 @@ elseif (isset($_REQUEST['form'])) {
 		'show_inherited_tags' => getRequest('show_inherited_tags', 0),
 		'correlation_mode' => getRequest('correlation_mode', ZBX_TRIGGER_CORRELATION_NONE),
 		'correlation_tag' => getRequest('correlation_tag', ''),
-		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED)
+		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED),
+		'context' => getRequest('context'),
+		'backurl' => getRequest('backurl')
 	];
 
 	// render view
@@ -676,6 +610,12 @@ elseif (hasRequest('action') && getRequest('action') === 'trigger.masscopyto' &&
 	echo (new CView('configuration.copy.elements', $data))->getOutput();
 }
 else {
+	$data = [
+		'context' => getRequest('context')
+	];
+
+	$prefix = ($data['context'] === 'host') ? 'web.hosts.' : 'web.templates.';
+
 	$filter_groupids_ms = [];
 	$filter_hostids_ms = [];
 
@@ -700,7 +640,7 @@ else {
 		$filter_name = '';
 		$filter_priority = [];
 		$filter_groupids = [];
-		$filter_hostids = getRequest('filter_hostids', CProfile::getArray('web.triggers.filter_hostids', []));
+		$filter_hostids = getRequest('filter_hostids', CProfile::getArray($prefix.'triggers.filter_hostids', []));
 		if (count($filter_hostids) != 1) {
 			$filter_hostids = [];
 		}
@@ -711,25 +651,25 @@ else {
 		$filter_tags = [];
 	}
 	else {
-		$filter_inherited = CProfile::get('web.triggers.filter_inherited', -1);
-		$filter_discovered = CProfile::get('web.triggers.filter_discovered', -1);
-		$filter_dependent = CProfile::get('web.triggers.filter_dependent', -1);
-		$filter_name = CProfile::get('web.triggers.filter_name', '');
-		$filter_priority = CProfile::getArray('web.triggers.filter_priority', []);
-		$filter_groupids = CProfile::getArray('web.triggers.filter_groupids', []);
-		$filter_hostids = CProfile::getArray('web.triggers.filter_hostids', []);
-		$filter_state = CProfile::get('web.triggers.filter_state', -1);
-		$filter_status = CProfile::get('web.triggers.filter_status', -1);
-		$filter_value = CProfile::get('web.triggers.filter_value', -1);
-		$filter_evaltype = CProfile::get('web.triggers.filter.evaltype', TAG_EVAL_TYPE_AND_OR);
+		$filter_inherited = CProfile::get($prefix.'triggers.filter_inherited', -1);
+		$filter_discovered = CProfile::get($prefix.'triggers.filter_discovered', -1);
+		$filter_dependent = CProfile::get($prefix.'triggers.filter_dependent', -1);
+		$filter_name = CProfile::get($prefix.'triggers.filter_name', '');
+		$filter_priority = CProfile::getArray($prefix.'triggers.filter_priority', []);
+		$filter_groupids = CProfile::getArray($prefix.'triggers.filter_groupids', []);
+		$filter_hostids = CProfile::getArray($prefix.'triggers.filter_hostids', []);
+		$filter_state = CProfile::get($prefix.'triggers.filter_state', -1);
+		$filter_status = CProfile::get($prefix.'triggers.filter_status', -1);
+		$filter_value = CProfile::get($prefix.'triggers.filter_value', -1);
+		$filter_evaltype = CProfile::get($prefix.'triggers.filter.evaltype', TAG_EVAL_TYPE_AND_OR);
 
 		$filter_tags = [];
 
-		foreach (CProfile::getArray('web.triggers.filter.tags.tag', []) as $i => $tag) {
+		foreach (CProfile::getArray($prefix.'triggers.filter.tags.tag', []) as $i => $tag) {
 			$filter_tags[] = [
 				'tag' => $tag,
-				'value' => CProfile::get('web.triggers.filter.tags.value', null, $i),
-				'operator' => CProfile::get('web.triggers.filter.tags.operator', null, $i)
+				'value' => CProfile::get($prefix.'triggers.filter.tags.value', null, $i),
+				'operator' => CProfile::get($prefix.'triggers.filter.tags.operator', null, $i)
 			];
 		}
 	}
@@ -748,14 +688,27 @@ else {
 	}
 
 	if ($filter_hostids) {
-		$filter_hostids = API::Host()->get([
-			'output' => ['hostid', 'name'],
-			'hostids' => $filter_hostids,
-			'templated_hosts' => true,
-			'editable' => true,
-			'preservekeys' => true
-		]);
-		$filter_hostids_ms = CArrayHelper::renameObjectsKeys($filter_hostids, ['hostid' => 'id']);
+		if ($data['context'] === 'host') {
+			$filter_hostids = API::Host()->get([
+				'output' => ['hostid', 'name'],
+				'hostids' => $filter_hostids,
+				'editable' => true,
+				'preservekeys' => true
+			]);
+
+			$filter_hostids_ms = CArrayHelper::renameObjectsKeys($filter_hostids, ['hostid' => 'id']);
+		}
+		else {
+			$filter_hostids = API::Template()->get([
+				'output' => ['templateid', 'name'],
+				'templateids' => $filter_hostids,
+				'editable' => true,
+				'preservekeys' => true
+			]);
+
+			$filter_hostids_ms = CArrayHelper::renameObjectsKeys($filter_hostids, ['templateid' => 'id']);
+		}
+
 		$filter_hostids = array_keys($filter_hostids_ms);
 	}
 
@@ -764,9 +717,9 @@ else {
 		return (bool) $v['tag'];
 	});
 
-	$sort = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'description'));
-	$sortorder = getRequest('sortorder', CProfile::get('web.'.$page['file'].'.sortorder', ZBX_SORT_UP));
-	$active_tab = CProfile::get('web.triggers.filter.active', 1);
+	$sort = getRequest('sort', CProfile::get($prefix.$page['file'].'.sort', 'description'));
+	$sortorder = getRequest('sortorder', CProfile::get($prefix.$page['file'].'.sortorder', ZBX_SORT_UP));
+	$active_tab = CProfile::get($prefix.'triggers.filter.active', 1);
 
 	// Get triggers (build options).
 	$options = [
@@ -775,11 +728,11 @@ else {
 		'groupids' => $filter_groupids ? $filter_groupids_enriched : null,
 		'editable' => true,
 		'dependent' => ($filter_dependent != -1) ? $filter_dependent : null,
-		'templated' => ($filter_value != -1) ? false : null,
+		'templated' => ($filter_value == -1) ? ($data['context'] === 'template') : false,
 		'inherited' => ($filter_inherited != -1) ? $filter_inherited : null,
 		'preservekeys' => true,
 		'sortfield' => $sort,
-		'limit' => $config['search_limit'] + 1
+		'limit' => CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1
 	];
 
 	if ($sort === 'status') {
@@ -846,7 +799,9 @@ else {
 
 	CPagerHelper::savePage($page['file'], $page_num);
 
-	$paging = CPagerHelper::paginate($page_num, $prefetched_triggers, $sortorder, new CUrl('triggers.php'));
+	$paging = CPagerHelper::paginate($page_num, $prefetched_triggers, $sortorder,
+		(new CUrl('triggers.php'))->setArgument('context', $data['context'])
+	);
 
 	// fetch triggers
 	$triggers = [];
@@ -906,12 +861,15 @@ else {
 
 	$show_info_column = false;
 	$show_value_column = false;
-	foreach ($triggers as $trigger) {
-		foreach ($trigger['hosts'] as $trigger_host) {
-			if (in_array($trigger_host['status'], [HOST_STATUS_NOT_MONITORED, HOST_STATUS_MONITORED])) {
-				$show_value_column = true;
-				$show_info_column = true;
-				break 2;
+
+	if ($data['context'] === 'host') {
+		foreach ($triggers as $trigger) {
+			foreach ($trigger['hosts'] as $trigger_host) {
+				if (in_array($trigger_host['status'], [HOST_STATUS_NOT_MONITORED, HOST_STATUS_MONITORED])) {
+					$show_value_column = true;
+					$show_info_column = true;
+					break 2;
+				}
 			}
 		}
 	}
@@ -944,20 +902,20 @@ else {
 		unset($dependencyTrigger);
 	}
 
-	CProfile::update('web.'.$page['file'].'.sort', $sort, PROFILE_TYPE_STR);
-	CProfile::update('web.'.$page['file'].'.sortorder', $sortorder, PROFILE_TYPE_STR);
+	CProfile::update($prefix.$page['file'].'.sort', $sort, PROFILE_TYPE_STR);
+	CProfile::update($prefix.$page['file'].'.sortorder', $sortorder, PROFILE_TYPE_STR);
 
 	if (getRequest('filter_set')) {
-		CProfile::update('web.triggers.filter_inherited', $filter_inherited, PROFILE_TYPE_INT);
-		CProfile::update('web.triggers.filter_discovered', $filter_discovered, PROFILE_TYPE_INT);
-		CProfile::update('web.triggers.filter_dependent', $filter_dependent, PROFILE_TYPE_INT);
-		CProfile::update('web.triggers.filter_name', $filter_name, PROFILE_TYPE_STR);
-		CProfile::updateArray('web.triggers.filter_priority', $filter_priority, PROFILE_TYPE_INT);
-		CProfile::updateArray('web.triggers.filter_groupids', $filter_groupids, PROFILE_TYPE_ID);
-		CProfile::updateArray('web.triggers.filter_hostids', $filter_hostids, PROFILE_TYPE_ID);
-		CProfile::update('web.triggers.filter_state', $filter_state, PROFILE_TYPE_INT);
-		CProfile::update('web.triggers.filter_status', $filter_status, PROFILE_TYPE_INT);
-		CProfile::update('web.triggers.filter.evaltype', $filter_evaltype, PROFILE_TYPE_INT);
+		CProfile::update($prefix.'triggers.filter_inherited', $filter_inherited, PROFILE_TYPE_INT);
+		CProfile::update($prefix.'triggers.filter_discovered', $filter_discovered, PROFILE_TYPE_INT);
+		CProfile::update($prefix.'triggers.filter_dependent', $filter_dependent, PROFILE_TYPE_INT);
+		CProfile::update($prefix.'triggers.filter_name', $filter_name, PROFILE_TYPE_STR);
+		CProfile::updateArray($prefix.'triggers.filter_priority', $filter_priority, PROFILE_TYPE_INT);
+		CProfile::updateArray($prefix.'triggers.filter_groupids', $filter_groupids, PROFILE_TYPE_ID);
+		CProfile::updateArray($prefix.'triggers.filter_hostids', $filter_hostids, PROFILE_TYPE_ID);
+		CProfile::update($prefix.'triggers.filter_state', $filter_state, PROFILE_TYPE_INT);
+		CProfile::update($prefix.'triggers.filter_status', $filter_status, PROFILE_TYPE_INT);
+		CProfile::update($prefix.'triggers.filter.evaltype', $filter_evaltype, PROFILE_TYPE_INT);
 
 		$filter_tags_fmt = ['tags' => [], 'values' => [], 'operators' => []];
 
@@ -971,35 +929,35 @@ else {
 			$filter_tags_fmt['operators'][] = $filter_tag['operator'];
 		}
 
-		CProfile::updateArray('web.triggers.filter.tags.tag', $filter_tags_fmt['tags'], PROFILE_TYPE_STR);
-		CProfile::updateArray('web.triggers.filter.tags.value', $filter_tags_fmt['values'], PROFILE_TYPE_STR);
-		CProfile::updateArray('web.triggers.filter.tags.operator', $filter_tags_fmt['operators'], PROFILE_TYPE_INT);
+		CProfile::updateArray($prefix.'triggers.filter.tags.tag', $filter_tags_fmt['tags'], PROFILE_TYPE_STR);
+		CProfile::updateArray($prefix.'triggers.filter.tags.value', $filter_tags_fmt['values'], PROFILE_TYPE_STR);
+		CProfile::updateArray($prefix.'triggers.filter.tags.operator', $filter_tags_fmt['operators'], PROFILE_TYPE_INT);
 
 		if ($show_value_column) {
-			CProfile::update('web.triggers.filter_value', $filter_value, PROFILE_TYPE_INT);
+			CProfile::update($prefix.'triggers.filter_value', $filter_value, PROFILE_TYPE_INT);
 		}
 	}
 	elseif (getRequest('filter_rst')) {
-		CProfile::deleteIdx('web.triggers.filter_inherited');
-		CProfile::deleteIdx('web.triggers.filter_discovered');
-		CProfile::deleteIdx('web.triggers.filter_dependent');
-		CProfile::deleteIdx('web.triggers.filter_name');
-		CProfile::deleteIdx('web.triggers.filter_priority');
-		CProfile::deleteIdx('web.triggers.filter_groupids');
+		CProfile::deleteIdx($prefix.'triggers.filter_inherited');
+		CProfile::deleteIdx($prefix.'triggers.filter_discovered');
+		CProfile::deleteIdx($prefix.'triggers.filter_dependent');
+		CProfile::deleteIdx($prefix.'triggers.filter_name');
+		CProfile::deleteIdx($prefix.'triggers.filter_priority');
+		CProfile::deleteIdx($prefix.'triggers.filter_groupids');
 
 		if (count($filter_hostids) != 1) {
-			CProfile::deleteIdx('web.triggers.filter_hostids');
+			CProfile::deleteIdx($prefix.'triggers.filter_hostids');
 		}
 
-		CProfile::deleteIdx('web.triggers.filter_state');
-		CProfile::deleteIdx('web.triggers.filter_status');
-		CProfile::deleteIdx('web.triggers.filter.evaltype');
-		CProfile::deleteIdx('web.triggers.filter.tags.tag');
-		CProfile::deleteIdx('web.triggers.filter.tags.value');
-		CProfile::deleteIdx('web.triggers.filter.tags.operator');
+		CProfile::deleteIdx($prefix.'triggers.filter_state');
+		CProfile::deleteIdx($prefix.'triggers.filter_status');
+		CProfile::deleteIdx($prefix.'triggers.filter.evaltype');
+		CProfile::deleteIdx($prefix.'triggers.filter.tags.tag');
+		CProfile::deleteIdx($prefix.'triggers.filter.tags.value');
+		CProfile::deleteIdx($prefix.'triggers.filter.tags.operator');
 
 		if ($show_value_column) {
-			CProfile::deleteIdx('web.triggers.filter_value');
+			CProfile::deleteIdx($prefix.'triggers.filter_value');
 		}
 	}
 
@@ -1009,12 +967,10 @@ else {
 	}
 
 	sort($filter_hostids);
-	$checkbox_hash = crc32(implode('', $filter_hostids));
 
-	$data = [
-		'config' => $config,
+	$data += [
 		'triggers' => $triggers,
-		'profileIdx' => 'web.triggers.filter',
+		'profileIdx' => $prefix.'triggers.filter',
 		'active_tab' => $active_tab,
 		'sort' => $sort,
 		'sortorder' => $sortorder,
@@ -1037,7 +993,8 @@ else {
 		'parent_templates' => getTriggerParentTemplates($triggers, ZBX_FLAG_DISCOVERY_NORMAL),
 		'paging' => $paging,
 		'dep_triggers' => $dep_triggers,
-		'tags' => makeTags($triggers, true, 'triggerid', ZBX_TAG_COUNT_DEFAULT, $filter_tags)
+		'tags' => makeTags($triggers, true, 'triggerid', ZBX_TAG_COUNT_DEFAULT, $filter_tags),
+		'allowed_ui_conf_templates' => CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES)
 	];
 
 	// render view
